==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ThisQuarterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { ThisQuarterExpressionDescription } from "./ThisQuarterExpressionDescription";
/**
 * @hidden
 */
var ThisQuarterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ThisQuarterExpressionDescriptionMetadata, _super);
    function ThisQuarterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ThisQuarterExpressionDescriptionMetadata.b = function (a) {
        if (ThisQuarterExpressionDescriptionMetadata.a == null) {
            ThisQuarterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ThisQuarterExpressionDescriptionMetadata.c(ThisQuarterExpressionDescriptionMetadata.a);
        }
        if (a.j(ThisQuarterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(ThisQuarterExpressionDescriptionMetadata.a);
    };
    ThisQuarterExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    ThisQuarterExpressionDescriptionMetadata.d = function (a) {
        ThisQuarterExpressionDescriptionMetadata.b(a);
        a.aa("ThisQuarterExpression", function () { return new ThisQuarterExpressionDescription(); });
        a.z("ThisQuarterExpression", ThisQuarterExpressionDescriptionMetadata.a);
    };
    ThisQuarterExpressionDescriptionMetadata.$t = markType(ThisQuarterExpressionDescriptionMetadata, 'ThisQuarterExpressionDescriptionMetadata');
    ThisQuarterExpressionDescriptionMetadata.a = null;
    return ThisQuarterExpressionDescriptionMetadata;
}(Base));
export { ThisQuarterExpressionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ThisQuarterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { ThisQuarterExpressionDescription } from "./ThisQuarterExpressionDescription";
/**
 * @hidden
 */
var ThisQuarterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ThisQuarterExpressionDescriptionMetadata, _super);
    function ThisQuarterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ThisQuarterExpressionDescriptionMetadata.b = function (a) {
        if (ThisQuarterExpressionDescriptionMetadata.a == null) {
            ThisQuarterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ThisQuarterExpressionDescriptionMetadata.c(ThisQuarterExpressionDescriptionMetadata.a);
        }
        if (a.k(ThisQuarterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(ThisQuarterExpressionDescriptionMetadata.a);
    };
    ThisQuarterExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    ThisQuarterExpressionDescriptionMetadata.d = function (a) {
        ThisQuarterExpressionDescriptionMetadata.b(a);
        a.ac("ThisQuarterExpression", function () { return new ThisQuarterExpressionDescription(); });
        a.ab("ThisQuarterExpression", ThisQuarterExpressionDescriptionMetadata.a);
    };
    ThisQuarterExpressionDescriptionMetadata.$t = markType(ThisQuarterExpressionDescriptionMetadata, 'ThisQuarterExpressionDescriptionMetadata');
    ThisQuarterExpressionDescriptionMetadata.a = null;
    return ThisQuarterExpressionDescriptionMetadata;
}(Base));
export { ThisQuarterExpressionDescriptionMetadata };
